@@ -1,6 +1,7 @@
 from .between import between
 from .email import email
 from .extremes import Min, Max
+from .finnish_business_id import finnish_business_id
 from .ip_address import ipv4, ipv6
 from .length import length
 from .mac_address import mac_address
@@ -13,6 +14,7 @@ from .uuid import uuid
 __all__ = (
     between,
     email,
+    finnish_business_id,
     ipv4,
     ipv6,
     length,
@@ -27,4 +29,4 @@ __all__ = (
 )
 
 
-__version__ = '0.3'
+__version__ = '0.4'
